Skip to contents

function to create a css file for the generic styling of html/shiny according to the CI/CD of the city of Zurich

Usage

get_generic_css(destination_filepath = "ssz.css")

Arguments

destination_filepath

optional, defaults to "ssz.css" in the local folder. if provided, give full path and filename, like "path/folder/file.css"

Examples

get_generic_css()
#> [1] TRUE