Skip to contents

function to generate radioButtons with the custom ssz (label) styling

Usage

sszRadioButtons(inputId, label, choices, ...)

Arguments

inputId

inputId parameter for radioButtons

label

label parameter for radioButtons

choices

choices parameter for radioButtons

...

further named parameters for radioBuTons (e.g. inline = TRUE for horizontal layout)

Value

the return of radioButtons with modified labels, wrapped in a div with class "radioDiv"

Details

a "sszRadioButton" is added to the output of radioButtons, and a "sszRadioButton-label" class is added to the appropriate child. the whole thing is wrapped in a div with class "radioDiv"

Examples

if (FALSE) { # \dontrun{
inst / examples / sszRadioButtons / app.r
} # }